SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 16447300;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 311849;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 7227367;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 21519412;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 1010958;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 6272416;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 21888502;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 21990949;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 20331580;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 231276;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 100674;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 20830528;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 21099526;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 162896;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 22424788;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 20626921;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 22734214;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 21279544;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 17870599;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 18751324;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 18264283;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 19475803;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 20477941;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 22929382;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 11299489;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 16570483;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 18391414;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 21000451;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 11369977;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 9886051;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 22617568;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 98054;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 970516;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 21260029;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 22622557;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 14762728;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 5482534;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 10250275;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 23344813;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 23856562;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 13223461;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 1064845;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 23453899;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 22384789;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 23982805;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 15075358;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 322187;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 23953330;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 19325545;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 21385060;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 19965796;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 18780277;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 19454293;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 2755;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 4255870;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 13723486;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 20179597;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 23510062;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 16567711;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 24067630;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 10373758;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 15871777;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 21612955;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 23441950;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 5361274;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 22348093;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 23802799;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 12903265;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 24184564;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 14005723;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 509416;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 12879952;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 6731659;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 148030;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 21090781;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 18679972;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 18965725;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 18882277;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 20902840;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 8542948;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 14997619;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 21554698;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 21069571;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 12146479;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 1205378;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 771107;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 22281868;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 22178384;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 17838109;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 14603353;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 10563076;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 724840;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 21519640;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 23695144;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 16192327;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 19444645;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 10318822;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 18910300;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 1572259;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 6401680;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 35054;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 17775658;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 23704582;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 19154980;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 21021124;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 9070591;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 1340709;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 21384403;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 19945789;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 10049827;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 113943;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 20827714;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 20361523;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 7068424;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 5935387;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 14371921;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 9424240;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 1683293;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 22602985;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 244688;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 12584464;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 14582767;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 11167036;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 22451221;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 12978052;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 19790521;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 15742261;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 16908067;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 2495578;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 4380979;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 1633467;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 19866526;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 21271384;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 22486705;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 21202006;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 21070687;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 11091565;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 17985739;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 22445365;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 23772880;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 20778388;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 230179;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 16679578;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 22065736;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 3924838;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 7212070;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 22983808;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 7384096;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 2604;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 650932;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 10900831;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 24037393;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 22596106;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 22180217;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 18547225;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 1743991;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 956997;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 22961593;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 7082143;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 15972304;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 11266375;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 35774;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 22151192;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 330149;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 18494080;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 983810;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 21804988;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 23189848;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 11064361;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 1902205;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 19899028;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 20726233;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 22751884;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 2132557;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 22594396;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 296158;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 9946492;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 19451524;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 7763785;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 16341391;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 3796804;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 1839;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 23462068;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 18318652;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 11669965;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 10501075;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 20027482;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 11583685;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 42586;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 4131496;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 6068563;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 70659;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 1286379;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 20402113;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 16842985;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 16461736;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 14211247;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 183742;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 16037572;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 23579041;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 6611935;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 23591458;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 24392791;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 22161892;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 13974904;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 160848;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 7918660;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 20085736;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 1602419;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 16923829;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 11986633;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 18207637;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 12885928;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 6375496;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 10795105;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 18557131;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 17450179;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 17800144;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 15354772;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 23144515;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 15549385;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 22716352;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 21860068;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 1940077;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 23150329;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 8049691;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 11386126;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 21803221;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 21633664;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 23955877;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 20122396;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 23727913;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 13983208;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 22711375;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 13466764;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 19050478;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 23175136;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 22450234;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 1384335;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 18792373;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 7746310;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 17369587;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 12874756;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 18735907;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 12260821;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 18635233;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 17963329;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 22934281;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 17201476;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 22418647;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 13094539;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 752731;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 18160555;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 12757027;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 18597361;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 7433614;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 5690881;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 21118276;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 20661916;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 21953854;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 20837995;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 23306071;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 727709;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 24061714;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 43861;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 23931547;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 12957628;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 23807914;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 781569;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 13607117;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 20642545;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 19101886;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 7752361;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 20350945;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 22312993;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 22495489;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 1293793;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 6601483;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 11552092;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 864913;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 3979828;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 20662477;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 7407445;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 17868073;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 21155629;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 12989809;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 76719;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 19830214;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 17709220;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 14661577;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 23264026;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 22911616;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 6463993;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 16677091;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 21631570;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 21111193;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 5899678;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 18159811;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 1450043;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 23534269;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 1126596;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 13574801;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 12634069;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 23823433;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 14910490;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 19860319;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 68737;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 21617599;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 21634810;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 11430829;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 430818;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 14317369;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 22336622;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 22912675;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 18436540;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 11961628;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 950406;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 7178023;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 23262754;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 16829410;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 88731;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 1606607;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 14457415;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 17923123;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 13992169;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 23736148;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 20923675;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 142203;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 20361103;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 8205184;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 22002982;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 17587633;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 20991970;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 13051300;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 19243744;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 21625381;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 1402053;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 13104817;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 5270176;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 10227019;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 502139;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 24065761;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 23648725;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 10145665;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 14614057;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 11614093;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 21999106;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 2040193;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 11369239;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 153901;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 6798544;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 16963450;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 21370864;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 19999834;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 11247409;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 22176314;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 18207316;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 9458011;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 21261418;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 14765356;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 23618191;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 23444548;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 13084939;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 115226;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 22111729;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 20570326;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 23281543;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 21768016;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 17586049;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 9347143;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 23251951;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 9837085;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 22189843;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 23836445;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 1750735;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 48974;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 82604;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 23429713;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 965907;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 7941676;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 1057301;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 23599927;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 18250675;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 24033715;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 20667007;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 9721663;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 13107145;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 23406805;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 15822511;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 22922992;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 10548637;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 2437834;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 16796794;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 12040550;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 4238398;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 10793239;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 21486094;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 180393;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 17748835;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 11223940;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 1048199;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 404917;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 1227383;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 150422;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 22563523;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 12328705;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 13166551;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 19248274;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 20380597;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 207901;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 20994013;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 20533000;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 21254380;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 6531613;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 87499;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 13607531;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 12998860;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 22963318;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 24130984;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 22186279;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 6217882;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 23694580;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 11542936;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 18403198;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 20501191;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 1839229;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 13587707;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 337148;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 237922;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 6695203;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 23766385;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 21893869;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 22044565;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 18356998;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 22856353;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 1940974;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 21064438;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 22491703;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 10853794;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 19208605;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 7763506;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 15633052;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 12926980;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 15619141;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 21637108;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 21421138;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 16675555;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 23824468;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 23111200;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 977212;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 1529177;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 1757487;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 17069044;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 20982994;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 15248224;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 2958436;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 20438797;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 241692;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 726991;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 187304;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 22278727;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 20699560;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 1161170;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 17143366;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 3936901;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 23147602;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 942211;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 6360139;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 22845019;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 22262671;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 21277948;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 658955;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 21823405;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 22222549;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 138960;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 11868505;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 7570210;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 14717959;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 4520284;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 21945835;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 20676250;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 14875207;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 20030020;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 11187883;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 160366;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 21047998;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 16827436;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 5243680;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 1246330;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 21091438;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 17759953;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 23344696;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 4914007;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 24238993;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 19353595;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 18776962;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 11816812;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 12775981;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 443080;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 12073216;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 21723667;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 10503499;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 23835697;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 22324529;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 9956137;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 23427451;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 23787157;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 21645604;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 12783328;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 15502978;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 24361354;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 21571144;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 18269953;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 22764370;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 23332939;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 17378284;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 24127903;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 1659835;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 387614;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 1813771;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 24186424;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 11454142;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 153960;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 22881175;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 16404439;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 22564360;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 21138574;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 23913517;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 10573612;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 18990535;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 16654072;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 20622772;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 18536539;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 20430181;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 15758722;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 11805436;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 15469597;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 23249362;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 16311706;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 19907104;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 58364;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 21300892;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 16706377;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 22226776;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 11186215;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 5629135;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 8035720;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 12074653;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 12855724;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 18727279;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 23688403;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 22348117;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 22437676;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 21731815;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 22160845;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 23529592;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 21760885;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 12896245;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 114634;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 23317843;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 23082139;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 24280942;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 23247967;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 22473928;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 23060461;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 23778226;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 15046105;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 3236848;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 7631659;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 10507519;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 17615887;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 13046434;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 20554606;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 24049246;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 18408787;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 1497109;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 17905573;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 21754438;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 5538790;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 10829980;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 13992391;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 66504;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 22512982;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 15652897;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 21276235;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 18770644;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 15662662;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 10161970;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 18641509;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 22280074;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 21379552;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 21264430;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 23068549;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 10772845;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 2038669;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 20626948;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 104064;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 13087750;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 4433956;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 21344539;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 16071850;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 24005692;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 20648488;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 10638034;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 486867;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 22998298;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 13243405;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 21667987;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 13190524;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 8192197;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 21771235;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 17734588;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 23111911;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 17761390;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 12888601;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 15711313;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 21179218;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 11486290;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 18691054;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 20880718;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 21637201;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 169649;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 21040945;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 5734555;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 21137548;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 24005935;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 20993179;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 12570466;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 10187791;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 20212057;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 19626166;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 81078;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 17776366;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 17087953;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 20242894;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 18246898;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 23578141;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 20801083;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 20841418;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 23750032;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 12102745;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 201007;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 21402886;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 3063307;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 23086156;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 22628254;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 21579151;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 22474825;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 22146962;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 18094117;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 9650656;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 23760628;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 24305014;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 11900293;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 18012577;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 23059279;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 17079028;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 12899989;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 21689104;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 22357813;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 17844745;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 3243655;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 16392643;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 23500396;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 11521879;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 794328;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 6331864;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 20151244;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 70595;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 21229069;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 10210294;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 461137;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 20300068;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 23946133;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 21738727;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 10631026;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 795837;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 21329731;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 6521590;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 22407961;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 22230415;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 11333239;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 21675262;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 24131203;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 22526434;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 19025272;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 21344743;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 10787479;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 14535805;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 21879637;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 5692288;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 105589;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 20571772;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 11376784;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 14908795;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 15896320;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 1599005;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 12751282;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 16631110;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 20863162;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 20590756;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 17304466;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 11337502;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 12787234;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 20975842;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 1067283;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 15276505;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 19962931;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 162300;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 6444100;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 19411474;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 9790033;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 22141253;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 18325648;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 23809642;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 1354799;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 23919961;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 644217;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 20771050;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 20695744;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 6470599;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 19296766;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 1010887;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 3025;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 20735257;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 22412722;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 24300940;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 22731619;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 14886760;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 18884518;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 159137;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 7506880;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 24278878;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 15465016;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 3170437;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 11018566;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 65976;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 1712285;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 11839687;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 24275806;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 23469325;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 21247126;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 13037131;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 810429;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 21335863;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 24066841;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 22365193;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 24136081;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 7518508;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 24186001;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 168287;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 9688087;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 17368204;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 9316975;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 10008478;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 9939709;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 13130248;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 485384;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 10588285;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 13344565;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 755766;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 17206873;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 21464908;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 10552819;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 513165;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 60844;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 193578;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 23509153;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 19839511;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 21190726;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 145604;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 4825291;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 12910402;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 17079070;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 13436371;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 195125;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 10275760;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 21999427;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 1284975;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 23621008;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 285178;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 13220617;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 6796894;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 17023966;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 8123776;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 17449006;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 21668662;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 20096968;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 16708717;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 10760635;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 22733080;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 23401273;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 23510617;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 14476834;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 11308495;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 24268282;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 18114196;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 20086945;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 22009009;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 6842632;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 550606;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 22984000;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 6651847;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 23181460;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 1073005;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 24287764;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 22624171;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 13252402;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 10718590;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 9286879;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 143202;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 12203728;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 211231;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 11864926;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 19677487;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 21810544;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 17221114;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 10764424;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 17899918;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 229129;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 1098537;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 875109;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 24175219;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 19913062;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 22563961;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 19100509;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 10032397;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 14467660;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 22418446;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 19683055;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 23531476;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 1598765;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 10355422;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 3670951;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 8048485;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 5203336;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 22183948;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 23813230;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 9813811;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 10296184;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 13266838;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 23520373;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 23705500;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 23761111;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 5693914;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 24276121;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 21962428;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 16279855;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 23125432;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 22129157;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 17607211;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 13073128;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 16297969;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 1868509;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 6990250;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 8084032;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 21613498;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 6359830;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 22080205;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 20358655;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 19484734;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 2243911;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 20661463;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 22811053;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 10448905;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 21427147;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 17219197;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 18216478;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 23375059;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 16199908;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 9936940;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 22433392;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 15615931;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 17751211;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 17921125;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 21772687;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 12905191;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 5748610;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 15028942;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 17452492;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 934261;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 20769670;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 4256095;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 9615136;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 22405135;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 5826757;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 19455331;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 11221384;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 23065603;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 1464787;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 23255512;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 21046240;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 11152147;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 19340260;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 20790796;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 22751983;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 10663036;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 12671212;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 16979245;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 16826713;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 21908368;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 215363;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 12887305;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 740471;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 2006116;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 24022195;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 11873545;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 23613532;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 22024711;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 15808192;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 22510834;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 10158082;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 20062666;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 2155900;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 10996243;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 23732275;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 17657869;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 12938056;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 21366607;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 23533687;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 16908964;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 21581755;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 13146670;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 13200580;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 18423466;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 22459213;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 13949116;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 17158843;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 20406778;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 21648643;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 22846792;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 20046997;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 13194094;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 19874278;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 21553033;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 20714647;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 11354182;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 10487221;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 1618385;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 50359;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 18610975;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 20180476;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 20858191;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 15064975;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 20795134;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 24270307;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 15478012;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 22397041;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 21325057;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 11193616;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 19598311;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 19724464;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 15102916;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 16182112;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 16384213;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 22145798;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 1367921;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 256297;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 21791194;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 2228362;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 6101386;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 20889169;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 17157937;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 19942327;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 23165935;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 7650367;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 16051609;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 23190688;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 12277228;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 18669307;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 13831414;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 21223684;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 9615727;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 23473615;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 5967373;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 4269664;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 20641135;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 24255571;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 6999850;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 5422;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 23999812;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 19762219;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 21861691;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 20138260;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 24344110;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 698117;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 21801520;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 23957683;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 2109130;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 214548;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 10387462;
SELECT uniq(UserID), sum(Sign), sum(Sign * PageViews), sum(Sign * Duration) FROM test.visits WHERE CounterID = 10972597;
